Highs_getPresolvedColName

Function Highs_getPresolvedColName 

pub unsafe extern "C" fn Highs_getPresolvedColName(
    highs: *const c_void,
    col: HighsInt,
    name: *mut c_char,
) -> HighsInt
Get the name of a column of the presolved LP.

@param col The index of the column to query. @param name A pointer in which to store the name of the column. This must have length kHighsMaximumStringLength.

@returns A kHighsStatus constant indicating whether the call succeeded.