Highs_passLinearObjectives

Function Highs_passLinearObjectives 

pub unsafe extern "C" fn Highs_passLinearObjectives(
    highs: *const c_void,
    num_linear_objective: HighsInt,
    weight: *const f64,
    offset: *const f64,
    coefficients: *const f64,
    abs_tolerance: *const f64,
    rel_tolerance: *const f64,
    priority: *const HighsInt,
) -> HighsInt
Passes multiple linear objective data to HiGHS, clearing any such data already in HiGHS

@param highs A pointer to the Highs instance. @param weight A pointer to the weights of the linear objective, with its positive/negative sign determining whether it is minimized or maximized during lexicographic optimization @param offset A pointer to the objective offsets @param coefficients A pointer to the objective coefficients @param abs_tolerance A pointer to the absolute tolerances used when constructing objective constraints during lexicographic optimization @param rel_tolerance A pointer to the relative tolerances used when constructing objective constraints during lexicographic optimization @param priority A pointer to the priorities of the objectives during lexicographic optimization

@returns A kHighsStatus constant indicating whether the call succeeded.