pub unsafe extern "C" fn Highs_deleteColsByRange(
highs: *mut c_void,
from_col: HighsInt,
to_col: HighsInt,
) -> HighsIntExpand description
Delete multiple adjacent columns.
@param highs A pointer to the Highs instance. @param from_col The index of the first column to delete. @param to_col The index of the last column to delete.
@returns A kHighsStatus constant indicating whether the call succeeded.