pub unsafe extern "C" fn Highs_getColByName(
highs: *const c_void,
name: *const c_char,
col: *mut HighsInt,
) -> HighsIntExpand description
Get the index of a column from its name.
If multiple columns have the same name, or if no column exists with name,
this function returns kHighsStatusError.
@param name A pointer of the name of the column to query. @param col A pointer in which to store the index of the column
@returns A kHighsStatus constant indicating whether the call succeeded.