pub unsafe extern "C" fn Highs_getColsByRange(
highs: *const c_void,
from_col: HighsInt,
to_col: HighsInt,
num_col: *mut HighsInt,
costs: *mut f64,
lower: *mut f64,
upper: *mut f64,
num_nz: *mut HighsInt,
matrix_start: *mut HighsInt,
matrix_index: *mut HighsInt,
matrix_value: *mut f64,
) -> HighsIntExpand description
Get data associated with multiple adjacent columns from the model.
To query the constraint coefficients, this function should be called twice.
First, call this function with matrix_start, matrix_index, and
matrix_value as NULL. This call will populate num_nz with the number of
nonzero elements in the corresponding section of the constraint matrix.
Second, allocate new matrix_index and matrix_value arrays of length
num_nz and call this function again to populate the new arrays with their
contents.
@param highs A pointer to the Highs instance.
@param from_col The first column for which to query data for.
@param to_col The last column (inclusive) for which to query data for.
@param num_col A HighsInt populated with the number of columns got from
the model (this should equal to_col - from_col + 1).
@param costs An array of size [to_col - from_col + 1] for the column
cost coefficients.
@param lower An array of size [to_col - from_col + 1] for the column
lower bounds.
@param upper An array of size [to_col - from_col + 1] for the column
upper bounds.
@param num_nz A HighsInt to be populated with the number of non-zero
elements in the constraint matrix.
@param matrix_start An array of size [to_col - from_col + 1] with the start
indices of each column in matrix_index and
matrix_value.
@param matrix_index An array of size [num_nz] with the row indices of each
element in the constraint matrix.
@param matrix_value An array of size [num_nz] with the non-zero elements of
the constraint matrix.
@returns A kHighsStatus constant indicating whether the call succeeded.