pub unsafe extern "C" fn Highs_getPresolvedRowName(
highs: *const c_void,
row: HighsInt,
name: *mut c_char,
) -> HighsIntExpand description
Get the name of a row of the presolved LP.
@param row The index of the row to query.
@param name A pointer in which to store the name of the row. This must
have length kHighsMaximumStringLength.
@returns A kHighsStatus constant indicating whether the call succeeded.