Highs_setCallbackSolution

Function Highs_setCallbackSolution 

pub unsafe extern "C" fn Highs_setCallbackSolution(
    data_in: *mut HighsCallbackDataIn,
    num_entries: HighsInt,
    value: *const f64,
) -> HighsInt
Set a solution within a callback by passing a subset of the values.

For any values that are unavailable/unknown, pass kHighsUndefined.

@param data_in A pointer to the callback input data instance. @param num_entries Number of variables in the set @param value An array of length [num_entries <= num_col] with column solution values.

@returns A kHighsStatus constant indicating whether the call succeeded.